summaryrefslogtreecommitdiffstats
path: root/kdvi/dviRenderer.h
diff options
context:
space:
mode:
Diffstat (limited to 'kdvi/dviRenderer.h')
-rw-r--r--kdvi/dviRenderer.h102
1 files changed, 51 insertions, 51 deletions
diff --git a/kdvi/dviRenderer.h b/kdvi/dviRenderer.h
index 98f0f4bd..863a2786 100644
--- a/kdvi/dviRenderer.h
+++ b/kdvi/dviRenderer.h
@@ -15,11 +15,11 @@
#include "fontpool.h"
#include <kurl.h>
-#include <qintdict.h>
-#include <qpointarray.h>
-#include <qtimer.h>
-#include <qvaluestack.h>
-#include <qvaluevector.h>
+#include <tqintdict.h>
+#include <tqpointarray.h>
+#include <tqtimer.h>
+#include <tqvaluestack.h>
+#include <tqvaluevector.h>
class Anchor;
class DocumentWidget;
@@ -41,11 +41,11 @@ extern const int MFResolutions[];
class DVI_SourceFileAnchor {
public:
DVI_SourceFileAnchor() {}
- DVI_SourceFileAnchor(const QString& name, Q_UINT32 ln, Q_UINT32 pg, const Length& _distance_from_top)
+ DVI_SourceFileAnchor(const TQString& name, Q_UINT32 ln, Q_UINT32 pg, const Length& _distance_from_top)
: fileName(name), line(ln), page(pg),
distance_from_top(_distance_from_top) {}
- QString fileName;
+ TQString fileName;
Q_UINT32 line;
Q_UINT32 page;
Length distance_from_top;
@@ -76,7 +76,7 @@ struct drawinf {
TeXFontDefinition *fontp;
set_char_proc set_char_p;
- QIntDict<TeXFontDefinition> *fonttable;
+ TQIntDict<TeXFontDefinition> *fonttable;
TeXFontDefinition *_virtual;
};
@@ -87,20 +87,20 @@ class dviRenderer : public DocumentRenderer, bigEndianByteReader
Q_OBJECT
public:
- dviRenderer(QWidget *parent);
+ dviRenderer(TQWidget *parent);
~dviRenderer();
- virtual bool setFile(const QString &fname, const KURL &base);
+ virtual bool setFile(const TQString &fname, const KURL &base);
class dvifile *dviFile;
- void setPrefs(bool flag_showPS, const QString &editorCommand, bool useFontHints );
+ void setPrefs(bool flag_showPS, const TQString &editorCommand, bool useFontHints );
virtual bool supportsTextSearch() const {return true;}
bool showPS() { return _postscript; }
int curr_page() { return current_page+1; }
- virtual bool isValidFile(const QString& fileName) const;
+ virtual bool isValidFile(const TQString& fileName) const;
/** This method will try to parse the reference part of the DVI
@@ -108,7 +108,7 @@ public:
number, or src:<line><filename>) and see if a corresponding
section of the DVI file can be found. If so, it returns an
anchor to that section. If not, it returns an invalid anchor. */
- virtual Anchor parseReference(const QString &reference);
+ virtual Anchor parseReference(const TQString &reference);
// These should not be public... only for the moment
void read_postamble();
@@ -120,23 +120,23 @@ public:
void applicationDoSpecial(char * cp);
void special(long nbytes);
- void printErrorMsgForSpecials(const QString& msg);
- void color_special(const QString& cp);
- void html_href_special(const QString& cp);
+ void printErrorMsgForSpecials(const TQString& msg);
+ void color_special(const TQString& cp);
+ void html_href_special(const TQString& cp);
void html_anchor_end();
void draw_page();
public slots:
- void exportPS(const QString& fname = QString::null, const QString& options = QString::null, KPrinter* printer = 0);
+ void exportPS(const TQString& fname = TQString::null, const TQString& options = TQString::null, KPrinter* printer = 0);
void exportPDF();
void showInfo();
- void handleSRCLink(const QString &linkText, QMouseEvent *e, DocumentWidget *widget);
+ void handleSRCLink(const TQString &linkText, TQMouseEvent *e, DocumentWidget *widget);
void embedPostScript();
void abortExternalProgramm();
/** simply emits "setStatusBarText( QString::null )". This is used
in dviRenderer::mouseMoveEvent(), see the explanation there. */
void clearStatusBar();
@@ -150,7 +150,7 @@ public slots:
signals:
/** Passed through to the top-level kpart. */
- // void setStatusBarText( const QString& );
+ // void setStatusBarText( const TQString& );
private slots:
/** This method shows a dialog that tells the user that source
@@ -169,17 +169,17 @@ private:
/** This method parses a color specification of type "gray 0.5", "rgb
0.5 0.7 1.0", "hsb ...", "cmyk .." or "PineGreen". See the source
code for details. */
- QColor parseColorSpecification(const QString& colorSpec);
+ TQColor parseColorSpecification(const TQString& colorSpec);
/** This map contains the colors which are known by name. This field
is initialized in the method parseColorSpecification() as soon as
it is needed. */
- QMap<QString, QColor> namedColors;
+ TQMap<TQString, TQColor> namedColors;
/* This method locates special PDF characters in a string and
replaces them by UTF8. See Section 3.2.3 of the PDF reference
guide for information */
- QString PDFencodingToQString(const QString& pdfstring);
+ TQString PDFencodingToQString(const TQString& pdfstring);
void setResolution(double resolution_in_DPI);
@@ -193,19 +193,19 @@ private:
void prescan_embedPS(char *cp, Q_UINT8 *);
void prescan_removePageSizeInfo(char *cp, Q_UINT8 *);
void prescan_parseSpecials(char *cp, Q_UINT8 *);
- void prescan_ParsePapersizeSpecial(const QString& cp);
- void prescan_ParseBackgroundSpecial(const QString& cp);
- void prescan_ParseHTMLAnchorSpecial(const QString& cp);
- void prescan_ParsePSHeaderSpecial(const QString& cp);
- void prescan_ParsePSBangSpecial(const QString& cp);
- void prescan_ParsePSQuoteSpecial(const QString& cp);
- void prescan_ParsePSSpecial(const QString& cp);
- void prescan_ParsePSFileSpecial(const QString& cp);
- void prescan_ParseSourceSpecial(const QString& cp);
+ void prescan_ParsePapersizeSpecial(const TQString& cp);
+ void prescan_ParseBackgroundSpecial(const TQString& cp);
+ void prescan_ParseHTMLAnchorSpecial(const TQString& cp);
+ void prescan_ParsePSHeaderSpecial(const TQString& cp);
+ void prescan_ParsePSBangSpecial(const TQString& cp);
+ void prescan_ParsePSQuoteSpecial(const TQString& cp);
+ void prescan_ParsePSSpecial(const TQString& cp);
+ void prescan_ParsePSFileSpecial(const TQString& cp);
+ void prescan_ParseSourceSpecial(const TQString& cp);
void prescan_setChar(unsigned int ch);
/* */
- QValueVector<PreBookmark> prebookmarks;
+ TQValueVector<PreBookmark> prebookmarks;
@@ -216,15 +216,15 @@ private:
/** Shrink factor. Units are not quite clear */
double shrinkfactor;
- QString errorMsg;
+ TQString errorMsg;
/** Methods which handle certain special commands. */
- void epsf_special(const QString& cp);
- void source_special(const QString& cp);
+ void epsf_special(const TQString& cp);
+ void source_special(const TQString& cp);
/** TPIC specials */
- void TPIC_setPen_special(const QString& cp);
- void TPIC_addPath_special(const QString& cp);
+ void TPIC_setPen_special(const TQString& cp);
+ void TPIC_addPath_special(const TQString& cp);
void TPIC_flushPath_special();
/** This timer is used to delay clearing of the statusbar. Clearing
@@ -232,39 +232,39 @@ private:
mouse moves over a block of text that contains source
hyperlinks. The signal timeout() is connected to the method
clearStatusBar() of *this. */
- QTimer clearStatusBarTimer;
+ TQTimer clearStatusBarTimer;
// List of source-hyperlinks on all pages. This vector is generated
// when the DVI-file is first loaded, i.e. when draw_part is called
// with PostScriptOutPutString != NULL
- QValueVector<DVI_SourceFileAnchor> sourceHyperLinkAnchors;
+ TQValueVector<DVI_SourceFileAnchor> sourceHyperLinkAnchors;
// If not NULL, the text currently drawn represents a source
// hyperlink to the (relative) URL given in the string;
- QString *source_href;
+ TQString *source_href;
// If not NULL, the text currently drawn represents a hyperlink to
// the (relative) URL given in the string;
- QString *HTML_href;
+ TQString *HTML_href;
- QString editorCommand;
+ TQString editorCommand;
/** Stack for register compounds, used for the DVI-commands PUSH/POP
as explained in section 2.5 and 2.6.2 of the DVI driver standard,
Level 0, published by the TUG DVI driver standards committee. */
- QValueStack<struct framedata> stack;
+ TQValueStack<struct framedata> stack;
/** A stack where color are stored, according to the documentation of
DVIPS */
- QValueStack<QColor> colorStack;
+ TQValueStack<TQColor> colorStack;
/** The global color is to be used when the color stack is empty */
- QColor globalColor;
+ TQColor globalColor;
/** If PostScriptOutPutFile is non-zero, then no rendering takes
place. Instead, the PostScript code which is generated by the
\special-commands is written to the PostScriptString */
- QString *PostScriptOutPutString;
+ TQString *PostScriptOutPutString;
ghostscript_interface *PS_interface;
@@ -284,13 +284,13 @@ private:
fontProgressDialog *progress;
KShellProcess *proc;
KPrinter *export_printer;
- QString export_fileName;
- QString export_tmpFileName;
- QString export_errorString;
+ TQString export_fileName;
+ TQString export_tmpFileName;
+ TQString export_errorString;
/** Data required for handling TPIC specials */
float penWidth_in_mInch;
- QPointArray TPIC_path;
+ TQPointArray TPIC_path;
Q_UINT16 number_of_elements_in_path;
struct drawinf currinf;
@@ -120,23 +120,23 @@ public:
void embedPostScript();
void abortExternalProgramm();
- /** simply emits "setStatusBarText( QString::null )". This is used
+ /** simply emits "setStatusBarText( TQString::null )". This is used
in dviRenderer::mouseMoveEvent(), see the explanation there. */
void clearStatusBar();